@@ -13,12 +13,7 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-if __name__ == "__main__":
-    import uvicorn
+from argilla.cli.app import app
 
-    uvicorn.run(
-        "argilla:app",
-        port=6900,
-        host="0.0.0.0",
-        access_log=True,
-    )
+if __name__ == "__main__":
+    app()
