@@ -11,9 +11,13 @@
 #  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
+from typing import List, Union
+
+from argilla.client.feedback.schemas.enums import FieldTypes, MetadataPropertyTypes
+from argilla.pydantic_v1 import StrictFloat, StrictInt, StrictStr
 
 FETCHING_BATCH_SIZE = 250
 PUSHING_BATCH_SIZE = 32
 DELETE_DATASET_RECORDS_MAX_NUMBER = 100
 
-FIELD_TYPE_TO_PYTHON_TYPE = {"text": str}
+FIELD_TYPE_TO_PYTHON_TYPE = {FieldTypes.text: str}
