@@ -13,11 +13,14 @@
 #  limitations under the License.
 
 from argilla.client.feedback.training.base import ArgillaTrainer
-from argilla.client.feedback.training.schemas import (
+from argilla.client.feedback.training.schemas.base import (
     TrainingTask,
+    TrainingTaskForChatCompletion,
     TrainingTaskForDPO,
     TrainingTaskForPPO,
+    TrainingTaskForQuestionAnswering,
     TrainingTaskForRM,
+    TrainingTaskForSentenceSimilarity,
     TrainingTaskForSFT,
     TrainingTaskForTextClassification,
     TrainingTaskMapping,  # <- Deprecated
@@ -27,11 +30,14 @@ from argilla.client.feedback.training.schemas import (
 __all__ = [
     "ArgillaTrainer",
     "TrainingTask",
-    "TrainingTaskForTextClassification",
-    "TrainingTaskForSFT",
-    "TrainingTaskForRM",
-    "TrainingTaskForPPO",
+    "TrainingTaskForChatCompletion",
     "TrainingTaskForDPO",
+    "TrainingTaskForPPO",
+    "TrainingTaskForQuestionAnswering",
+    "TrainingTaskForRM",
+    "TrainingTaskForSentenceSimilarity",
+    "TrainingTaskForSFT",
+    "TrainingTaskForTextClassification",
     "TrainingTaskMapping",
     "TrainingTaskMappingForTextClassification",
 ]
